[−][src]Enum superconf::SuperError
Primary error enum for superconf, storing the common errors faced.
Variants
When a line had a key but no value, e.g. my_key
When a line had a value but no key. This should ususally not happen when parsing due to the nature of the library.
ElementExists(SuperValue)When adding elements and two are named with the same key, e.g:
my_value original
my_value this_will_error
IOError(Error)An IO error stemming from parse_file.